@@ -13,18 +13,19 @@
 # ----------------------------------------------------------------------
 
 package Text::BibTeX;
+use Text::BibTeX::Name;
+use Text::BibTeX::NameFormat;
 
 use 5.008001;                          # needed for Text::BibTeX::Entry
 
 use strict;
-#use UNIVERSAL qw(isa can);              # for 'check_class' subroutine
 use Carp;
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
 require Exporter;
 require DynaLoader;
 
-our $VERSION='0.62_01';
+our $VERSION='0.75_01';
 
 @ISA = qw(Exporter DynaLoader);
 %EXPORT_TAGS = (nodetypes => [qw(BTAST_STRING BTAST_MACRO BTAST_NUMBER)],
@@ -45,9 +46,34 @@ our $VERSION='0.62_01';
               @{$EXPORT_TAGS{'nodetypes'}},
               @{$EXPORT_TAGS{'nameparts'}},
               @{$EXPORT_TAGS{'joinmethods'}},
-              'check_class', 'display_list');
+              'check_class', 'display_list' );
 @EXPORT = @{$EXPORT_TAGS{'metatypes'}};
 
+use Encode;
+use Unicode::Normalize;
+
+sub _process_result {
+    my ( $self, $result, $encoding ) = @_;
+
+    if ( $encoding eq "utf-8" ) {
+        return NFC( decode( $encoding, $result ) );
+    }
+    else { return $result; }
+
+}
+
+sub _process_argument {
+    my ( $self, $value, $encoding ) = @_;
+
+    if ( $encoding eq "utf-8" ) {
+        return encode( $encoding, $value );
+    }
+    else {
+        return $value;
+    }
+}
+
+
 =head1 NAME
 
 Text::BibTeX - interface to read and parse BibTeX files
@@ -56,10 +82,10 @@ Text::BibTeX - interface to read and parse BibTeX files
 
    use Text::BibTeX;
 
-   $bibfile = new Text::BibTeX::File "foo.bib";
-   $newfile = new Text::BibTeX::File ">newfoo.bib";
+   $bibfile = Text::BibTeX::File->new("foo.bib");
+   $newfile = Text::BibTeX::File->new(">newfoo.bib");
 
-   while ($entry = new Text::BibTeX::Entry $bibfile)
+   while ($entry = Text::BibTeX::Entry->($bibfile))
    {
       next unless $entry->parse_ok;
 
@@ -395,11 +421,11 @@ sub bibloop (&$;$)
    my $file;
    while ($file = shift @$files)
    {
-      my $bib = new Text::BibTeX::File $file;
+      my $bib = Text::BibTeX::File->new($file);
       
       while (! $bib->eof())
       {
-         my $entry = new Text::BibTeX::Entry $bib;
+         my $entry = Text::BibTeX::Entry->new($bib);
          next unless $entry->parse_ok;
 
          my $result = &$action ($entry);
