@@ -7,7 +7,7 @@
 #              them is done by the Text::BibTeX::NameFormat class).
 # CREATED    : Nov 1997, Greg Ward
 # MODIFIED   : 
-# VERSION    : $Id: Name.pm 8423 2010-02-13 20:40:27Z ambs $
+# VERSION    : $Id$
 # COPYRIGHT  : Copyright (c) 1997-2000 by Gregory P. Ward.  All rights
 #              reserved.
 # 
@@ -22,6 +22,10 @@ require 5.004;
 
 use strict;
 use Carp;
+use vars qw'$VERSION';
+$VERSION = 0.75_01;
+
+use Text::BibTeX;
 
 =head1 NAME
 
@@ -29,15 +33,17 @@ Text::BibTeX::Name - interface to BibTeX-style author names
 
 =head1 SYNOPSIS
 
-   $name = new Text::BibTeX::Name;
+   use Text::BibTeX::Name;
+
+   $name = Text::BibTeX::Name->new();
    $name->split('J. Random Hacker');
    # or:
-   $name = new Text::BibTeX::Name ('J. Random Hacker');
+   $name = Text::BibTeX::Name->new('J. Random Hacker');
 
    @firstname_tokens = $name->part ('first');
    $lastname = join (' ', $name->part ('last'));
 
-   $format = new Text::BibTeX::NameFormat;
+   $format = Text::BibTeX::NameFormat->new();
    # ...customize $format...
    $formatted = $name->format ($format);
 
@@ -110,7 +116,7 @@ Note that every part is a list of tokens, even if there is only one
 token in that part; empty parts get empty token lists.  Every token is
 just a string.  Writing this example in actual code is simple:
 
-   $name = new Text::BibTeX::Name ("John Smith");  # or "Smith, John"
+   $name = Text::BibTeX::Name->new("John Smith");  # or "Smith, John"
    $name->part ('first');       # returns list ("John")
    $name->part ('last');        # returns list ("Smith")
    $name->part ('von');         # returns list ()
@@ -265,7 +271,7 @@ way is the job of another module: see L<Text::BibTeX::NameFormat>.
 
 =over 4
 
-=item new (CLASS [, NAME [, FILENAME, LINE, NAME_NUM]])
+=item new([ [OPTS,] NAME [, FILENAME, LINE, NAME_NUM]])
 
 Creates a new C<Text::BibTeX::Name> object.  If NAME is supplied, it
 must be a string containing a single name, and it will be be passed to
@@ -273,17 +279,41 @@ the C<split> method for further processing.  FILENAME, LINE, and
 NAME_NUM, if present, are all also passed to C<split> to allow better
 error messages.
 
+If the first argument is a hash reference, it is used to define
+configuration values. At the moment the available values are:
+
+=over 4 
+
+=item BINMODE
+
+Set the way Text::BibTeX deals with strings. By default it manages
+strings as bytes. You can set BINMODE to 'utf-8' to get NFC normalized
+UTF-8 strings.
+
+   Text::BibTeX::Name->new( { binmode => 'UTF-8' }, "Alberto Simões"});
+
+=back
+
 =cut
 
-sub new
-{
-   my ($class, $name, $filename, $line, $name_num) = @_;
+sub new {
+    my $class = shift;
+    my $opts = ref $_[0] eq 'HASH' ? shift : {};
 
-   $class = ref ($class) || $class;
-   my $self = bless {}, $class;
-   $self->split ($name, $filename, $line, $name_num, 1)
-      if (defined $name);
-   $self;
+    $opts->{ lc $_ } = $opts->{$_} for ( keys %$opts );
+
+    my ( $name, $filename, $line, $name_num ) = @_;
+
+    $class = ref($class) || $class;
+    my $self = bless { }, $class;
+
+    $self->{binmode} = 'bytes';
+    $self->{binmode} = 'utf-8'
+        if exists $opts->{binmode} && $opts->{binmode} =~ /utf-?8/i;
+
+    $self->split( $name, $filename, $line, $name_num, 1 )
+        if ( defined $name );
+    $self;
 }
 
 
@@ -313,7 +343,7 @@ sub split
    my ($self, $name, $filename, $line, $name_num) = @_;
 
    # Call the XSUB with default values if necessary
-   $self->_split ($name, $filename, 
+   $self->_split (Text::BibTeX->_process_argument($name, $self->{binmode}), $filename, 
                   defined $line ? $line : -1,
                   defined $name_num ? $name_num : -1,
                   1);
@@ -326,7 +356,7 @@ Returns the list of tokens in part PARTNAME of a name previously split with
 C<split>.  For example, suppose a C<Text::BibTeX::Name> object is created and
 initialized like this:
 
-   $name = new Text::BibTeX::Name;
+   $name = Text::BibTeX::Name->new();
    $name->split ('Charles Louis Xavier Joseph de la Vall{\'e}e Poussin');
 
 Then this code:
@@ -337,13 +367,18 @@ would return the list C<('de','la')>.
 
 =cut
 
-sub part
-{
-   my ($self, $partname) = @_;
+sub part {
+    my ( $self, $partname ) = @_;
 
-   croak "unknown name part" 
-      unless $partname =~ /^(first|von|last|jr)$/;
-   exists $self->{$partname} ? @{$self->{$partname}} : ();
+    croak "unknown name part"
+        unless $partname =~ /^(first|von|last|jr)$/;
+
+    if ( exists $self->{$partname} ) {
+        my @x = map { Text::BibTeX->_process_result($_, $self->{binmode}) }
+            @{ $self->{$partname} };
+        return @x > 1 ? @x : $x[0];
+    }
+    return undef;
 }
 
 
